==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/kinesis/kotlin/inputs/AnalyticsApplicationOutputLambdaArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kinesis.kotlin.inputs

import com.pulumi.aws.kinesis.inputs.AnalyticsApplicationOutputLambdaArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceArn The ARN of the Lambda function.
 * @property roleArn The ARN of the IAM Role used to access the Lambda function.
 */
public data class AnalyticsApplicationOutputLambdaArgs(
    public val resourceArn: Output<String>,
    public val roleArn: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.kinesis.inputs.AnalyticsApplicationOutputLambdaArgs> {
    override fun toJava(): com.pulumi.aws.kinesis.inputs.AnalyticsApplicationOutputLambdaArgs =
        com.pulumi.aws.kinesis.inputs.AnalyticsApplicationOutputLambdaArgs.builder()
            .resourceArn(resourceArn.applyValue({ args0 -> args0 }))
            .roleArn(roleArn.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AnalyticsApplicationOutputLambdaArgs].
 */
@PulumiTagMarker
public class AnalyticsApplicationOutputLambdaArgsBuilder internal constructor() {
    private var resourceArn: Output<String>? = null

    private var roleArn: Output<String>? = null

    /**
     * @param value The ARN of the Lambda function.
     */
    @JvmName("fowppdtlohdadbay")
    public suspend fun resourceArn(`value`: Output<String>) {
        this.resourceArn = value
    }

    /**
     * @param value The ARN of the IAM Role used to access the Lambda function.
     */
    @JvmName("walkekartxvbiqji")
    public suspend fun roleArn(`value`: Output<String>) {
        this.roleArn = value
    }

    /**
     * @param value The ARN of the Lambda function.
     */
    @JvmName("jkluoovygpygyqlm")
    public suspend fun resourceArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceArn = mapped
    }

    /**
     * @param value The ARN of the IAM Role used to access the Lambda function.
     */
    @JvmName("wewvvxdokbuocvor")
    public suspend fun roleArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roleArn = mapped
    }

    internal fun build(): AnalyticsApplicationOutputLambdaArgs = AnalyticsApplicationOutputLambdaArgs(
        resourceArn = resourceArn ?: throw PulumiNullFieldException("resourceArn"),
        roleArn = roleArn ?: throw PulumiNullFieldException("roleArn"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/kinesis/kotlin/inputs/AnalyticsApplicationOutputLambdaArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kinesis.kotlin.inputs

import com.pulumi.aws.kinesis.inputs.AnalyticsApplicationOutputLambdaArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceArn The ARN of the Lambda function.
 * @property roleArn The ARN of the IAM Role used to access the Lambda function.
 */
public data class AnalyticsApplicationOutputLambdaArgs(
    public val resourceArn: Output<String>,
    public val roleArn: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.kinesis.inputs.AnalyticsApplicationOutputLambdaArgs> {
    override fun toJava(): com.pulumi.aws.kinesis.inputs.AnalyticsApplicationOutputLambdaArgs =
        com.pulumi.aws.kinesis.inputs.AnalyticsApplicationOutputLambdaArgs.builder()
            .resourceArn(resourceArn.applyValue({ args0 -> args0 }))
            .roleArn(roleArn.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AnalyticsApplicationOutputLambdaArgs].
 */
@PulumiTagMarker
public class AnalyticsApplicationOutputLambdaArgsBuilder internal constructor() {
    private var resourceArn: Output<String>? = null

    private var roleArn: Output<String>? = null

    /**
     * @param value The ARN of the Lambda function.
     */
    @JvmName("ncpvxdanqhaupwkd")
    public suspend fun resourceArn(`value`: Output<String>) {
        this.resourceArn = value
    }

    /**
     * @param value The ARN of the IAM Role used to access the Lambda function.
     */
    @JvmName("hnkhdhyracbrjsjc")
    public suspend fun roleArn(`value`: Output<String>) {
        this.roleArn = value
    }

    /**
     * @param value The ARN of the Lambda function.
     */
    @JvmName("lwaxjpyhfistkuxd")
    public suspend fun resourceArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceArn = mapped
    }

    /**
     * @param value The ARN of the IAM Role used to access the Lambda function.
     */
    @JvmName("cqvwmoyqpwsddltp")
    public suspend fun roleArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roleArn = mapped
    }

    internal fun build(): AnalyticsApplicationOutputLambdaArgs = AnalyticsApplicationOutputLambdaArgs(
        resourceArn = resourceArn ?: throw PulumiNullFieldException("resourceArn"),
        roleArn = roleArn ?: throw PulumiNullFieldException("roleArn"),
    )
}
